@@ -14,7 +14,7 @@
 #' set.seed(1)
 #' s <- sim_dfa(num_trends = 1, num_ts = 3, num_years = 30)
 #' s$y_sim[1, 15] <- s$y_sim[1, 15] - 6
-#' plot(s$y_sim[1,], type = "o")
+#' plot(s$y_sim[1, ], type = "o")
 #' abline(v = 15, col = "red")
 #' # only 1 chain and 250 iterations used so example runs quickly:
 #' m <- fit_dfa(y = s$y_sim, num_trends = 1, iter = 50, chains = 1, nu_fixed = 2)
@@ -23,7 +23,6 @@
 #' print(p)
 #' # a 1 in 1000 probability if was from a normal distribution:
 #' find_swans(r, plot = TRUE, threshold = 0.001)
-#'
 #' @references
 #' Anderson, S.C., Branch, T.A., Cooper, A.B., and Dulvy, N.K. 2017.
 #' Black-swan events in animal populations. Proceedings of the National Academy
@@ -33,9 +32,8 @@
 #' @importFrom stats pnorm
 
 find_swans <- function(rotated_modelfit,
-  threshold = 0.01,
-  plot = FALSE) {
-
+                       threshold = 0.01,
+                       plot = FALSE) {
   x <- rotated_modelfit$trends_mean
   d <- apply(x, 1, function(xx) c(NA, diff(xx)))
   sds <- apply(d, 2, sd, na.rm = TRUE) # sds != 1
@@ -63,7 +61,8 @@ find_swans <- function(rotated_modelfit,
       x = "time", y = "trend_value",
       color = "below_threshold"
     )) +
-      geom_point() + facet_wrap(~ trend_number)
+      geom_point() +
+      facet_wrap(~trend_number)
     print(g)
   }
   invisible(trends)
